@@ -1,7 +1,7 @@
-__version__ = '0.1.6'
+__version__ = '0.1.7'
 
 import exgrads.grad1
-import exgrads.trH
+from exgrads.trH import trH
 
 __all__ = [
 	'__version__',
